@@ -1,5 +1,6 @@
 import pandas
 import io
+import datetime
 
 
 class DataFrameToolkit:
@@ -19,6 +20,7 @@ class DataFrameToolkit:
                   decimal=".",
                   encoding="utf-8")
 
+        b_buf.seek(0)
         return b_buf.read()
 
     @classmethod
@@ -30,9 +32,11 @@ class DataFrameToolkit:
         """
         b_buf = io.BytesIO(b_data)
 
+        date_parser = lambda x: datetime.datetime.strptime(x, "%Y-%m-%d-%H-%M-%S-%f")
         df = pandas.read_csv(b_buf,
-                             index_col='timestamp',
-                             date_format="%Y-%m-%d-%H-%M-%S-%f",
+                             index_col='Timestamp',
+                             parse_dates=['Timestamp'],
+                             date_parser=date_parser,
                              sep=",",
                              decimal=".",
                              encoding="utf-8")
@@ -54,4 +58,3 @@ class DataFrameToolkit:
             else:
                 df_json[col] = list(df[col].values)
         return df_json
-
